/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.common.entity;

import java.io.Serializable;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;

import net.kldp.whitebear.common.log.Log;
import net.kldp.whitebear.common.variable.Messages;

public class QueryResult implements Serializable {
    private static final long serialVersionUID = 5283468688443026014L;
    public static int STATUS_ERROR=-1;
    public static int STATUS_OK=0;
    
    private int columnCount;
    private ArrayList datas;
    private ArrayList columnNames;
    private long startTime;
    private long endTime;
    private int status;
    private String query;
    private ArrayList columnTypes;
    private ArrayList columnTypeNames;
    private String msg;
    private int changeRowCount = -1;
    private boolean isSelectQuery;
    private ResultSet resultSet;
    private PreparedStatement preparedStatement;
    private boolean hasNext;
    
    public boolean isHasNext() {
        return hasNext;
    }

    public void setHasNext(boolean hasNext) {
        this.hasNext = hasNext;
    }

    public ResultSet getResultSet() {
        return resultSet;
    }

    public void setResultSet(ResultSet resultSet) {
        this.resultSet = resultSet;
    }

    public boolean isSelectQuery() {
        return isSelectQuery;
    }

    public void setSelectQuery(boolean isSelectQuery) {
        this.isSelectQuery = isSelectQuery;
    }

    public int getChangeRowCount() {
        return changeRowCount;
    }

    public void setChangeRowCount(int changeRowCount) {
        this.changeRowCount = changeRowCount;
    }

    public ArrayList getColumnTypes() {
        return columnTypes;
    }
    
    public Object getValue(int row, int column) {
        if (columnCount-1 < column || row > datas.size()-1) {
            return null;
        }
        return ((ArrayList)datas.get(row)).get(column);
    }

    public void setColumnTypes(ArrayList columnTypes) {
        this.columnTypes = columnTypes;
    }

    public void addColumnType(int type) {
        this.columnTypes.add(new Integer(type));
    }
    
    public void addColumnTypeName(String typeName) {
        this.columnTypeNames.add(typeName);
    }
    
    public String getQuery() {
        return query;
    }

    public void setQuery(String query) {
        this.query = query;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    public long getEndTime() {
        return endTime;
    }

    public void setEndTime(long endTime) {
        this.endTime = endTime;
    }

    public long getStartTime() {
        return startTime;
    }

    public void setStartTime(long startTime) {
        this.startTime = startTime;
    }

    public void setColumnCount(int columnCount) {
        this.columnCount = columnCount;
    }

    public int getColumnCount() {
        return columnCount;
    }

    public ArrayList getDatas() {
        return datas;
    }

    public void addRow(ArrayList row) {
        this.datas.add(row);
    }
    
    public QueryResult() {
        datas = new ArrayList();
        columnNames = new ArrayList();
        columnTypes = new ArrayList();
        columnTypeNames = new ArrayList();
    }
 
    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public void addColumnName(String columnName) {
        this.columnNames.add(columnName);
    }

    public ArrayList getColumnNames() {
        return columnNames;
    }

    public ArrayList getColumnTypeNames() {
        return columnTypeNames;
    }

    public PreparedStatement getPreparedStatement() {
        return preparedStatement;
    }

    public void setPreparedStatement(PreparedStatement preparedStatement) {
        this.preparedStatement = preparedStatement;
    }

    public void close() {
        try {
            if (preparedStatement!=null) {preparedStatement.close();}
            if (resultSet!=null) {
                resultSet.close();
                resultSet = null;
            }
        } catch (SQLException sqle) {
            Log.logger.error(Messages.LOG_MSG_00010, sqle);
        }
    }

}
