/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler;

import java.sql.SQLException;
import java.util.ArrayList;

import javax.swing.tree.DefaultMutableTreeNode;

import net.kldp.whitebear.common.entity.DbConnectInfo;
import net.kldp.whitebear.common.entity.TableRef;
import net.kldp.whitebear.common.entity.TableTreeNodeInfo;
import net.kldp.whitebear.handler.ui.swing.MainFrame;


public class MainHandler {
    private DefaultMutableTreeNode topTableNode;
    private JdbcHandler jdbcHandler;
    private QueryHandler queryHandler;
    private MainFrame mainFrame;
    
    public MainHandler(DbConnectInfo dbConnectInfo) throws SQLException {
        initialize(dbConnectInfo);
    }

    private void initialize(DbConnectInfo dbConnectInfo) throws SQLException {
        jdbcHandler = new JdbcHandler(dbConnectInfo);
        queryHandler = new QueryHandler(this);
        TableTreeNodeInfo topNodeInfo = new TableTreeNodeInfo();
        topNodeInfo.setType(TableTreeNodeInfo.NODE_TYPE_TOP);
        topNodeInfo.setInfo(dbConnectInfo.getDbName());
        topTableNode = new DefaultMutableTreeNode(topNodeInfo);
        makeTableTree();
        makeUI();
    }

    private void makeUI() {
        mainFrame = new MainFrame(this);
        mainFrame.setMainHandler(this);
        getMainFrame().getCenterPanel().getBrowserPanel().getTableTreePanel().setRoot(getTopTableNode());
        getMainFrame().setVisible(true);
    }
    
    public MainFrame getMainFrame() {
        return mainFrame;
    }
    
    /*
    private void addTreeNode(int parentNodeLevel, String parentNodeName, String nodeName) {
        DefaultMutableTreeNode node = topNode;
        for (;;) {
            if (node==null) {
                break;
            } else {
                int currentNodeLevel = node.getLevel();
                String currentNodeName = node.toString();
                
                if (currentNodeLevel == parentNodeLevel && currentNodeName.equals(parentNodeName)) {
                    node.add(new DefaultMutableTreeNode(nodeName));
                    break;
                }
                node = (DefaultMutableTreeNode)node.getNextNode();
            }
        }
    }
    */   
    
    private void makeTableTree() {
        ArrayList categories = jdbcHandler.getCategories(jdbcHandler.getDatabaseMetaData());
        if (categories!=null) {
            for (int i=0; i<categories.size(); i++) {
                String category = (String)categories.get(i); 
                TableTreeNodeInfo categoryInfo = new TableTreeNodeInfo();
                categoryInfo.setType(TableTreeNodeInfo.NODE_TYPE_CATEGORY);
                categoryInfo.setInfo(category);
                DefaultMutableTreeNode categoryNode = new DefaultMutableTreeNode(categoryInfo);
                ArrayList tables = jdbcHandler.getTables(jdbcHandler.getDatabaseMetaData(), category);
                if (tables!=null) {
                    for (int j=0; j<tables.size(); j++) {
                        TableRef tableRef = (TableRef)tables.get(j);
                        TableTreeNodeInfo tableTreeNodeInfo = new TableTreeNodeInfo();
                        tableTreeNodeInfo.setType(TableTreeNodeInfo.NODE_TYPE_TABLE);
                        tableTreeNodeInfo.setInfo(tableRef);
                        DefaultMutableTreeNode tableNode = new DefaultMutableTreeNode(tableTreeNodeInfo);
                        categoryNode.add(tableNode);
                    }
                }
                topTableNode.add(categoryNode);
            }            
        }
    }    

    /*
    private void makeViewTree() {
        ArrayList categories = jdbcHandler.getCategories(jdbcHandler.getDatabaseMetaData());
        if (categories!=null) {
            for (int i=0; i<categories.size(); i++) {
                String category = (String)categories.get(i); 
                DefaultMutableTreeNode categoryNode = new DefaultMutableTreeNode(category);
                
                ArrayList tables = jdbcHandler.getTables(jdbcHandler.getDatabaseMetaData(), category);
                if (tables!=null) {
                    for (int j=0; j<tables.size(); j++) {
                        TableRef t = (TableRef)tables.get(j);
                        if (t.getTABLE_TYPE().equals("VIEW")) {
                            categoryNode.add(new DefaultMutableTreeNode(t.getTABLE_NAME()));
                        }
                    }
                }
                topViewNode.add(categoryNode);
            }            
        }
    }
    */  
    
    public void close() {
        if (jdbcHandler!=null) {
            jdbcHandler.close();
            jdbcHandler = null;
        }
        if (mainFrame!=null) {
            mainFrame.dispose();
            mainFrame = null;
        }
        if (queryHandler!=null) {
            queryHandler.close();
            queryHandler = null;
        }
    }

    public QueryHandler getQueryHandler() {
        return queryHandler;
    }

    public JdbcHandler getJdbcHandler() {
        return jdbcHandler;
    }
    
    public DefaultMutableTreeNode getTopTableNode() {
        return topTableNode;
    }

}
