/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.table.DefaultTableModel;

import net.kldp.whitebear.common.entity.QueryResult;
import net.kldp.whitebear.common.log.Log;
import net.kldp.whitebear.common.variable.Messages;
import net.kldp.whitebear.handler.ui.swing.ReadOnlyTable;
import net.kldp.whitebear.handler.ui.swing.SqlPanel;




public class QueryHandler {
    private int maxQueryHistorySize = 50;
    private int executeQueryMaxRowCount = 100;
    private int executeNextMaxRowCount = 100;
    
    private ArrayList queryHistory;
    private QueryResultHandler queryResultHandler = null;
    private MainHandler mainHandler;
    
    public MainHandler getMainHandler() {
        return mainHandler;
    }

    public QueryHandler(MainHandler mainHandler) {
        this.mainHandler = mainHandler;
        queryHistory = new ArrayList();
    }
    
    public void executeQuery(SqlPanel sqlPanel) {
        if (queryResultHandler!=null && queryResultHandler.isAlive()==true) {
            Log.logger.error(Messages.LOG_MSG_00012);
            return;
        }
        
        queryResultHandler = new QueryResultHandler(this, sqlPanel);
        queryResultHandler.start();
    }

    public void executeNext(SqlPanel sqlPanel) {
        if (sqlPanel==null) {
            Log.logger.debug("SqlPanel is null.");
            return;
        }
        QueryResult queryResult = sqlPanel.getQueryResult();
        if (queryResult==null) {
            Log.logger.debug("QueryResult is null.");
            return;
        }

        ReadOnlyTable readOnlyTable = sqlPanel.getSqlResultPanel().getReadOnlyTable();
        
        ResultSet rs = queryResult.getResultSet();
        if (rs==null) {
            Log.logger.debug("ResultSet is null.");
            return;
        }

        try {
            for (int i=0; i<executeNextMaxRowCount; i++) {
                if (rs.next()){
                    Vector rowVector = new Vector();
                    for (int j=1; j<queryResult.getColumnCount()+1; j++) {
                        rowVector.add(rs.getObject((String)queryResult.getColumnNames().get(j-1)));
                    }
                    readOnlyTable.addRow(rowVector);
                } else {
                    showMsg(sqlPanel, "End of result");
                    if (queryResult!=null) {
                        queryResult.close();
                    }                    
                    break;                    
                }
            }
        } catch(SQLException sqle) {
            Log.logger.error(Messages.LOG_MSG_00024, sqle);
        }
    }
    
    public void addQuery(String query) {
        if (this.queryHistory.size()>maxQueryHistorySize) {
            queryHistory.remove(queryHistory.size()-1);
        }
        queryHistory.add(query);
    }
    
    private void showQueryResult(SqlPanel sqlPanel) {
        QueryResult queryResult = sqlPanel.getQueryResult();
        
        ReadOnlyTable readOnlyTable = new ReadOnlyTable(true);
        sqlPanel.getSqlResultPanel().setReadOnlyTable(readOnlyTable);
        
        DefaultTableModel defaultTableModel = (DefaultTableModel)readOnlyTable.getModel();
        
        if (queryResult.isSelectQuery()) {
            ArrayList columnNames = queryResult.getColumnNames();
            for (int i=0; i<queryResult.getColumnCount(); i++) {
                defaultTableModel.addColumn(columnNames.get(i));
            }

            readOnlyTable.autoResizeColumnWidth();
            
            ArrayList datas = queryResult.getDatas();
            for (int i=0; i<datas.size(); i++) {
                ArrayList rowList = (ArrayList)datas.get(i);
                readOnlyTable.addRow(rowList);
            }
            showMsg(sqlPanel, queryResult.getMsg());
        } else {
            if (queryResult.getChangeRowCount()==0){
                showMsg(sqlPanel, Messages.MSG_00001);
            } else if (queryResult.getChangeRowCount()>=1) {
                showMsg(sqlPanel, queryResult.getChangeRowCount()+" row(s) changed.");
            }
        }
    }
    
    private void showMsg(SqlPanel sqlPanel, String msg) {
        sqlPanel.getSqlResultPanel().getJtMsg().setText(msg);
    }
    
    private void showErrorMsg(SqlPanel sqlPanel) {
        //ReadOnlyTable readOnlyTable = new ReadOnlyTable(true);
        //sqlPanel.getSqlResultPanel().setReadOnlyTable(readOnlyTable);

        ReadOnlyTable readOnlyTable = sqlPanel.getSqlResultPanel().getReadOnlyTable();
        readOnlyTable.removeAllRows();
        showMsg(sqlPanel, sqlPanel.getQueryResult().getMsg());
    }    
    
    public void postExecuteQuery(SqlPanel sqlPanel) {
        QueryResult queryResult = sqlPanel.getQueryResult();
        if (queryResult.getStatus()==QueryResult.STATUS_OK) {
            Log.logger.debug("QueryResult Status : STATUS_OK");
            showQueryResult(sqlPanel);
        } else if (queryResult.getStatus()==QueryResult.STATUS_ERROR) {
            Log.logger.debug("QueryResult Status : STATUS_ERROR");
            showErrorMsg(sqlPanel);
        }
        queryResultHandler = null;
    }
    
    public void close() {
        for(int i=0; i<queryHistory.size(); i++) {
            queryHistory.remove(i);
        }
        queryHistory = null;
    }

    public int getExecuteNextMaxRowCount() {
        return executeNextMaxRowCount;
    }

    public void setExecuteNextMaxRowCount(int executeNextMaxRowCount) {
        this.executeNextMaxRowCount = executeNextMaxRowCount;
    }

    public int getExecuteQueryMaxRowCount() {
        return executeQueryMaxRowCount;
    }

    public void setExecuteQueryMaxRowCount(int executeQueryMaxRowCount) {
        this.executeQueryMaxRowCount = executeQueryMaxRowCount;
    }

}
