/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.StringTokenizer;

import net.kldp.whitebear.common.entity.QueryResult;
import net.kldp.whitebear.common.log.Log;
import net.kldp.whitebear.common.variable.Messages;
import net.kldp.whitebear.handler.ui.swing.SqlPanel;



public class QueryResultHandler extends Thread {
    private QueryHandler queryHandler;
    private JdbcHandler jdbcHandler;
    private String query;
    private SqlPanel sqlPanel;
    
    public QueryResultHandler(QueryHandler queryHandler, SqlPanel sqlPanel) {
        this.sqlPanel = sqlPanel;
        this.queryHandler = queryHandler;
        this.jdbcHandler = queryHandler.getMainHandler().getJdbcHandler();
        this.query = removeComment(this.sqlPanel.getSqlEditorPanel().getQuery());
        this.queryHandler.addQuery(query);
    }

    private String removeComment(String query) {
        StringTokenizer st = new StringTokenizer(query, "\n");
        StringBuffer sb = new StringBuffer();
        int count = st.countTokens();
        for (int i=0; i<count; i++) {
            String line = st.nextToken().trim();
            int idx = line.indexOf("--");
            if (idx > -1) {
                sb.append(line.substring(idx)+"\n");
            } else {
                sb.append(line+"\n");
            }
        }
        return sb.toString();
    }
    
    public void run() {
        QueryResult queryResult = null;
        try {
            queryResult = makeQueryResult(query);
        } catch (Exception e) {
            queryResult = new QueryResult();
            Log.logger.error(Messages.LOG_MSG_00022, e);
            queryResult.setStatus(QueryResult.STATUS_ERROR);
            queryResult.setMsg(e.toString());
        }
        
        sqlPanel.setQueryResult(queryResult);
        queryHandler.postExecuteQuery(sqlPanel);
    }

    /*
    private void close(Connection con, PreparedStatement pstmt, ResultSet rs) {
        try {
            if (con!=null) {con.close();}
            if (pstmt!=null) {pstmt.close();}
            if (rs!=null) {rs.close();}
        } catch (SQLException sqle) {
            Log.logger.error(Messages.LOG_MSG_00010, sqle);
        }
    }
    */
    
    private boolean isSelectQuery(String query) {
        String upperQuery = query.toUpperCase();
        if (upperQuery.indexOf("INSERT")>-1){
            return false;
        }
        if (upperQuery.indexOf("UPDATE")>-1){
            return false;
        }
        if (upperQuery.indexOf("DELETE")>-1){
            return false;
        }
        if (upperQuery.indexOf("CREATE")>-1){
            return false;
        }
        if (upperQuery.indexOf("DROP")>-1){
            return false;
        }
        return true;
    }
    
    private QueryResult makeQueryResult(String query) throws Exception {
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        QueryResult queryResult = new QueryResult();
        queryResult.setQuery(query);
        try {
            Connection con = jdbcHandler.getConnection(); 
            pstmt = con.prepareStatement(query);
            queryResult.setStartTime(Calendar.getInstance().getTimeInMillis());
            if (isSelectQuery(query)) {
                rs = pstmt.executeQuery();
                queryResult.setEndTime(Calendar.getInstance().getTimeInMillis());
                ResultSetMetaData rsMeta = rs.getMetaData();
                int columnCount = rsMeta.getColumnCount();
                Log.logger.debug("rsMeta.getColumnCount() : "+columnCount);
                queryResult.setColumnCount(columnCount);
                
                for (int i=1; i<=columnCount; i++) {
                    Log.logger.debug("rsMeta.getColumnName("+i+") : "+rsMeta.getColumnName(i));
                    Log.logger.debug("rsMeta.getColumnTypeName("+i+") : "+rsMeta.getColumnTypeName(i));
                    Log.logger.debug("rsMeta.getColumnType("+i+") : "+rsMeta.getColumnType(i));
                    
                    queryResult.addColumnName(rsMeta.getColumnName(i));
                    queryResult.addColumnTypeName(rsMeta.getColumnTypeName(i));
                    queryResult.addColumnType(rsMeta.getColumnType(i));
                }
                
                int rowCount=0;
                while(rs.next()) {
                    rowCount++;
                    
                    ArrayList row = new ArrayList();
                    for (int i=1; i<=columnCount; i++) {
                        Object o = rs.getObject(i);
                        row.add(o);
                    }
                    queryResult.addRow(row);
                    if (queryHandler.getExecuteNextMaxRowCount()<=rowCount) {
                        break;
                    }
                }
                
                if (rs.next()) {
                    queryResult.setHasNext(true);
                    rs.previous();
                } else {
                    queryResult.setHasNext(false);
                }                
                
                Log.logger.debug("rowCount : "+rowCount);
                queryResult.setResultSet(rs);
                queryResult.setPreparedStatement(pstmt);
                queryResult.setSelectQuery(true);
                queryResult.setStatus(QueryResult.STATUS_OK);                
            } else {
                int changeRowCount = pstmt.executeUpdate();
                queryResult.setEndTime(Calendar.getInstance().getTimeInMillis());
                queryResult.setChangeRowCount(changeRowCount);
                queryResult.setSelectQuery(false);
                queryResult.setStatus(QueryResult.STATUS_OK);
            }

        } catch (SQLException sqle) {
            Log.logger.error(Messages.LOG_MSG_00011, sqle);
            queryResult.setStatus(QueryResult.STATUS_ERROR);
            queryResult.setMsg(sqle.toString());
        }
        
        return queryResult;
    }
    
}
