package net.kldp.whitebear.handler;

import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.ListSelectionModel;
import javax.swing.UIManager;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.table.DefaultTableModel;

import net.kldp.whitebear.common.config.SessionInfoConfig;
import net.kldp.whitebear.common.entity.DbConnectInfo;
import net.kldp.whitebear.common.log.Log;
import net.kldp.whitebear.common.variable.DBTypes;
import net.kldp.whitebear.handler.ui.swing.ReadOnlyTable;
import net.kldp.whitebear.handler.ui.swing.StartUpDialog;

public class StartUpHandler implements ActionListener, ListSelectionListener, WindowListener {
    public static StartUpDialog startUpDialog;
    public static ArrayList mainHandlerList = null;
    public static SessionInfoConfig sessionInfoConfig = null;

    public static final String TABLE_HEADER_DB_TYPE = "DB Type";
    public static final String TABLE_HEADER_DB_NAME = "DB Name";
    public static final String TABLE_HEADER_DB_HOST = "Host";
    public static final String TABLE_HEADER_DB_PORT = "Port";
    public static final String TABLE_HEADER_DB_USERNAME = "User Name";
    
       
    public StartUpHandler() {
        startUpDialog = new StartUpDialog();
        StartUpHandler.startUpDialog.getBOk().addActionListener(this);
        StartUpHandler.startUpDialog.getBCancel().addActionListener(this);
        StartUpHandler.startUpDialog.getBDelete().addActionListener(this);
        StartUpHandler.startUpDialog.getBInsert().addActionListener(this);
        StartUpHandler.startUpDialog.getReadOnlyTable().getSelectionModel().addListSelectionListener(this);
        StartUpHandler.startUpDialog.addWindowListener(this);
        mainHandlerList = new ArrayList();
        sessionInfoConfig = new SessionInfoConfig();
        makeSessionInfoTable();
    }

    public void actionPerformed(java.awt.event.ActionEvent e) {
        if (e.getSource().equals(StartUpHandler.startUpDialog.getBOk())) {
            runMain();
        } else if (e.getSource().equals(StartUpHandler.startUpDialog.getBCancel())) {
            exit();          
        } else if (e.getSource().equals(StartUpHandler.startUpDialog.getBInsert())) {
            insertDbConnectInfo();
        } else if (e.getSource().equals(StartUpHandler.startUpDialog.getBDelete())) {
            deleteDbConnectInfo();
        }
    }
    
    private void runMain() {
        MainHandler mainHandler = null;
        try {
            mainHandler = new MainHandler(StartUpHandler.startUpDialog.getDbConnectInfo());
            mainHandlerList.add(mainHandler);
            StartUpHandler.startUpDialog.setVisible(false);
        } catch (SQLException sqle) {
            if (mainHandler!=null) {
                mainHandler.close();
                mainHandler = null;
            }
        }        
    }
    
    private void deleteDbConnectInfo() {
        if (StartUpHandler.startUpDialog.getReadOnlyTable().getModel() instanceof DefaultTableModel) {
            DefaultTableModel defaultTableModel = (DefaultTableModel)StartUpHandler.startUpDialog.getReadOnlyTable().getModel();
            int selectedRow = StartUpHandler.startUpDialog.getReadOnlyTable().getSelectedRow();
            defaultTableModel.removeRow(selectedRow);
        }
    }    
    
    private void insertDbConnectInfo() {
        if (StartUpHandler.startUpDialog.getReadOnlyTable().getModel() instanceof DefaultTableModel) {
            DbConnectInfo dbConnectInfo = StartUpHandler.startUpDialog.getDbConnectInfo();
            Vector rowVector = new Vector();
            rowVector.add(dbConnectInfo.getDbTypeName());
            rowVector.add(dbConnectInfo.getDbName());
            rowVector.add(dbConnectInfo.getHost());
            rowVector.add(dbConnectInfo.getPort());
            rowVector.add(dbConnectInfo.getUserName());
            StartUpHandler.startUpDialog.getReadOnlyTable().addRow(rowVector);        
        }
    }

    private void makeSessionInfoTable() {
        if (StartUpHandler.startUpDialog.getReadOnlyTable().getModel() instanceof DefaultTableModel) {
            DefaultTableModel defaultTableModel = (DefaultTableModel)StartUpHandler.startUpDialog.getReadOnlyTable().getModel();
            
            ArrayList ssesionInfoList = sessionInfoConfig.getDbConnectInfoList();
            
            defaultTableModel.addColumn(TABLE_HEADER_DB_TYPE);
            defaultTableModel.addColumn(TABLE_HEADER_DB_NAME);
            defaultTableModel.addColumn(TABLE_HEADER_DB_HOST);
            defaultTableModel.addColumn(TABLE_HEADER_DB_PORT);
            defaultTableModel.addColumn(TABLE_HEADER_DB_USERNAME);
            
            StartUpHandler.startUpDialog.getReadOnlyTable().autoResizeColumnWidth();
            
            for (int i=0; i<ssesionInfoList.size(); i++) {
                DbConnectInfo dbConnectInfo = (DbConnectInfo)ssesionInfoList.get(i);
                Vector rowVector = new Vector();
                rowVector.add(dbConnectInfo.getDbTypeName());
                rowVector.add(dbConnectInfo.getDbName());
                rowVector.add(dbConnectInfo.getHost());
                rowVector.add(dbConnectInfo.getPort());
                rowVector.add(dbConnectInfo.getUserName());
                StartUpHandler.startUpDialog.getReadOnlyTable().addRow(rowVector);
            }
        }
    }
    
    private void setDbInfoPanel(int selectedRow) {
        ReadOnlyTable readOnlyTable = StartUpHandler.startUpDialog.getReadOnlyTable();

        String dbTypeName = (String)readOnlyTable.getValueAt(selectedRow, TABLE_HEADER_DB_TYPE);
        String dbName     = (String)readOnlyTable.getValueAt(selectedRow, TABLE_HEADER_DB_NAME);
        String host       = (String)readOnlyTable.getValueAt(selectedRow, TABLE_HEADER_DB_HOST);
        String port       = (String)readOnlyTable.getValueAt(selectedRow, TABLE_HEADER_DB_PORT);
        String userName   = (String)readOnlyTable.getValueAt(selectedRow, TABLE_HEADER_DB_USERNAME);
        
        Log.logger.debug("dbTypeName : "+dbTypeName);
        Log.logger.debug("dbName     : "+dbName);
        Log.logger.debug("host       : "+host);
        Log.logger.debug("port       : "+port);
        Log.logger.debug("userName   : "+userName);

        DbConnectInfo dbConnectInfo = new DbConnectInfo();
        dbConnectInfo.setDbName(dbName);
        dbConnectInfo.setHost(host);
        dbConnectInfo.setPort(port);
        dbConnectInfo.setUserName(userName);
        dbConnectInfo.setDbtype(DBTypes.getDbType(dbTypeName));

        StartUpHandler.startUpDialog.setDbConnectInfo(dbConnectInfo);        
    }
    
    public void valueChanged(ListSelectionEvent e) {
        if (e.getValueIsAdjusting()) return;
        ListSelectionModel lsm = (ListSelectionModel)e.getSource();
        if (lsm.isSelectionEmpty()) {

        } else {
            int selectedRow = lsm.getMinSelectionIndex();
            setDbInfoPanel(selectedRow);
        }
    }

    public void windowActivated(WindowEvent e) {
        
    }

    public void windowClosed(WindowEvent e) {
        
    }

    public void windowClosing(WindowEvent e) {
        exit();
    }

    public void windowDeactivated(WindowEvent e) {
        
    }

    public void windowDeiconified(WindowEvent e) {
        
    }

    public void windowIconified(WindowEvent e) {
        
    }

    public void windowOpened(WindowEvent e) {
        
    }
    
    public static void exit() {
        if (mainHandlerList.size() > 0) {
            StartUpHandler.startUpDialog.setVisible(false);
        } else if (mainHandlerList.size() == 0) {
            sessionInfoConfig.store(StartUpHandler.startUpDialog.getReadOnlyTable());
            System.exit(1);
        }
    }    
    
    public static void main(String[] args) {
        try {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } catch (Exception e) {}
        new StartUpHandler();
    }    
    
}
