/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;


import javax.swing.JPanel;
import javax.swing.JSplitPane;

import net.kldp.whitebear.handler.MainHandler;

import java.awt.BorderLayout;

public class CenterPanel extends JPanel {
    private static final long serialVersionUID = -8553892534901646367L;
    private JSplitPane jSplitPane = null;
    private BrowserPanel browserPanel = null;
    private WorkSpacePanel workSpacePanel = null;
    private MainHandler mainHandler = null;

    public void setMainHandler(MainHandler mainHandler) {
        this.mainHandler = mainHandler;
        getWorkSpacePanel().setMainHandler(this.mainHandler);
        getBrowserPanel().setMainHandler(this.mainHandler);
    }
    
    /**
     * This is the default constructor
     */
    public CenterPanel() {
        super();
        initialize();
    }

    /**
     * This method initializes this
     * 
     * @return void
     */
    private void initialize() {
        this.setLayout(new BorderLayout());
        this.setSize(300, 200);
        this.add(getJSplitPane(), java.awt.BorderLayout.CENTER);
    }

    /**
     * This method initializes jSplitPane	
     * 	
     * @return javax.swing.JSplitPane	
     */
    private JSplitPane getJSplitPane() {
        if (jSplitPane == null) {
            jSplitPane = new JSplitPane();
            jSplitPane.setLeftComponent(getBrowserPanel());
            jSplitPane.setDividerLocation(150);
            jSplitPane.setRightComponent(getWorkSpacePanel());
        }
        return jSplitPane;
    }

    public BrowserPanel getBrowserPanel() {
        if (browserPanel == null) {
            browserPanel = new BrowserPanel();
        }
        return browserPanel;        
    }
    
    public WorkSpacePanel getWorkSpacePanel() {
        if (workSpacePanel == null) {
            workSpacePanel = new WorkSpacePanel();
        }
        return workSpacePanel;        
    }
    
}
