/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;


import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.util.ArrayList;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;

import net.kldp.whitebear.handler.MainHandler;
import net.kldp.whitebear.handler.StartUpHandler;


public class MainFrame extends JFrame implements WindowListener, ActionListener {
    private static final long serialVersionUID = 6130064998364444702L;
    private JPanel jContentPane = null;
    private CenterPanel centerPanel = null;
    private MainHandler mainHandler = null;
    private JMenuBar jJMenuBar = null;
    private JMenu jMenu = null;
    private JMenuItem jmConnect = null;
    private JMenuItem jmExit = null;
    private JMenu jMenu1 = null;
    private JMenuItem jmExecute = null;
    private JMenuItem jmExecuteNext = null;
    private JMenu jMenu2 = null;
    private JMenuItem jmNewSQL = null;
    public MainFrame() {
        super();
        initialize();
    }

    public MainFrame(MainHandler mainHandler) {
        super();
        this.mainHandler = mainHandler;
        initialize();
    }
    
    private void initialize() {
        this.setSize(640, 480);
        this.setJMenuBar(getJJMenuBar());
        this.setContentPane(getJContentPane());
        this.setTitle("whitebear");
        addWindowListener(this);
        getJmiConnect().addActionListener(this);
        getJmiExit().addActionListener(this);
        getJmExecute().addActionListener(this);
        getJmExecuteNext().addActionListener(this);
        getJmNewSQL().addActionListener(this);
        newSQL();
    }

    private JPanel getJContentPane() {
        if (jContentPane == null) {
            jContentPane = new JPanel();
            jContentPane.setLayout(new BorderLayout());
            jContentPane.add(getCenterPanel(), java.awt.BorderLayout.CENTER);
        }
        return jContentPane;
    }

    public CenterPanel getCenterPanel() {
        if (centerPanel == null) {
            centerPanel = new CenterPanel();
        }
        return centerPanel;
    }

    public void setMainHandler(MainHandler mainHandler) {
        this.mainHandler = mainHandler;
        getCenterPanel().setMainHandler(this.mainHandler);
    }
    
    public MainHandler getMainHandler() {
        return mainHandler;
    }

    private JMenuBar getJJMenuBar() {
        if (jJMenuBar == null) {
            jJMenuBar = new JMenuBar();
            jJMenuBar.add(getJMenu());
            jJMenuBar.add(getJMenu1());
            jJMenuBar.add(getJMenu2());
        }
        return jJMenuBar;
    }

    private JMenu getJMenu() {
        if (jMenu == null) {
            jMenu = new JMenu();
            jMenu.setText("File");
            jMenu.add(getJmiConnect());
            jMenu.add(getJmiExit());
        }
        return jMenu;
    }

    public JMenuItem getJmiConnect() {
        if (jmConnect == null) {
            jmConnect = new JMenuItem();
            jmConnect.setText("Connect");
            jmConnect.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_N, java.awt.Event.CTRL_MASK, false));
        }
        return jmConnect;
    }

    public JMenuItem getJmiExit() {
        if (jmExit == null) {
            jmExit = new JMenuItem();
            jmExit.setText("Exit");
            jmExit.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_F4, java.awt.Event.ALT_MASK, false));
        }
        return jmExit;
    }

    /**
     * This method initializes jMenu1	
     * 	
     * @return javax.swing.JMenu	
     */
    private JMenu getJMenu1() {
        if (jMenu1 == null) {
            jMenu1 = new JMenu();
            jMenu1.setText("Execute");
            jMenu1.add(getJmExecute());
            jMenu1.add(getJmExecuteNext());
        }
        return jMenu1;
    }

    /**
     * This method initializes jMenuItem	
     * 	
     * @return javax.swing.JMenuItem	
     */
    public JMenuItem getJmExecute() {
        if (jmExecute == null) {
            jmExecute = new JMenuItem();
            jmExecute.setText("Execute");
            jmExecute.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_F5, 0, false));
        }
        return jmExecute;
    }

    /**
     * This method initializes jmExecuteNext	
     * 	
     * @return javax.swing.JMenuItem	
     */
    public JMenuItem getJmExecuteNext() {
        if (jmExecuteNext == null) {
            jmExecuteNext = new JMenuItem();
            jmExecuteNext.setText("Execute Next");
            jmExecuteNext.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_F7, 0, false));
        }
        return jmExecuteNext;
    }

    /**
     * This method initializes jMenu2	
     * 	
     * @return javax.swing.JMenu	
     */
    private JMenu getJMenu2() {
        if (jMenu2 == null) {
            jMenu2 = new JMenu();
            jMenu2.setText("View");
            jMenu2.add(getJmNewSQL());
        }
        return jMenu2;
    }

    /**
     * This method initializes jmNewSqlPanel	
     * 	
     * @return javax.swing.JMenuItem	
     */
    public JMenuItem getJmNewSQL() {
        if (jmNewSQL == null) {
            jmNewSQL = new JMenuItem();
            jmNewSQL.setText("New SQL");
        }
        return jmNewSQL;
    }

    public void actionPerformed(ActionEvent e) {
        Object o = e.getSource();
        if (o.equals(getJmiConnect())) {
            StartUpHandler.startUpDialog.setVisible(true);
        } else if (o.equals(getJmiExit())) {
            closeMainFrame(this);
        } else if (o.equals(getJmExecute())) {
            executeQuery();
        } else if (o.equals(getJmExecuteNext())) {
            executeNext();
        } else if (o.equals(getJmNewSQL())) {
            newSQL();
        }
    }
    
    private void newSQL() {
        SqlPanel sqlPanel = new SqlPanel(this.getMainHandler());
        getCenterPanel().getWorkSpacePanel().getJTabbedPane().addTab(WorkSpacePanel.SQL_PANEL, sqlPanel);
        getCenterPanel().getWorkSpacePanel().getJTabbedPane().setSelectedComponent(sqlPanel);
    }
    
    private void executeQuery() {
        Component selectecdComponent = getCenterPanel().getWorkSpacePanel().getJTabbedPane().getSelectedComponent();
        if (selectecdComponent instanceof SqlPanel) {
            SqlPanel sqlPanel = (SqlPanel)selectecdComponent;
            getMainHandler().getQueryHandler().executeQuery(sqlPanel);
        }
    }
    
    public void executeNext() {
        Component selectecdComponent = getCenterPanel().getWorkSpacePanel().getJTabbedPane().getSelectedComponent();
        if (selectecdComponent instanceof SqlPanel) {
            SqlPanel sqlPanel = (SqlPanel)selectecdComponent;
            getMainHandler().getQueryHandler().executeNext(sqlPanel);
        }
    } 
    
    public void windowActivated(WindowEvent e) {
        
    }

    public void windowClosed(WindowEvent e) {

    }

    public void windowClosing(WindowEvent e) {
        closeMainFrame(e.getSource());
    }

    public void windowDeactivated(WindowEvent e) {
        
    }

    public void windowDeiconified(WindowEvent e) {
        
    }

    public void windowIconified(WindowEvent e) {
        
    }

    public void windowOpened(WindowEvent e) {
        
    }
 
    private void closeMainFrame(Object source) {
        if (source instanceof MainFrame) {
            ArrayList mainHandlerList = StartUpHandler.mainHandlerList;
            for (int i=0; i < mainHandlerList.size(); i++) {
                MainHandler mainHandler = (MainHandler)mainHandlerList.get(i);
                MainFrame listMainFrame = mainHandler.getMainFrame();
                MainFrame sourceMainFrame = (MainFrame)source;
                if (sourceMainFrame.equals(listMainFrame)) {
                    mainHandler.close();
                    mainHandlerList.remove(mainHandler);
                    if (mainHandlerList.size()==0) {
                        StartUpHandler.exit();
                    }
                    break;
                }
            }
        }        
    }    
}
