/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;

import java.awt.Font;
import java.awt.FontMetrics;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;

public class ReadOnlyTable extends JTable {
    private static final long serialVersionUID = -838766531426086894L;
    private boolean showRowNumber;
    
    public ReadOnlyTable(boolean showRowNumber){
        init(showRowNumber);
    }
    
    private void init(boolean showRowNumber) {
        this.showRowNumber = showRowNumber;
        this.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        this.setColumnSelectionAllowed(true);
        if (showRowNumber) {
            DefaultTableModel defaultTableModel = (DefaultTableModel)getModel();
            defaultTableModel.addColumn("No");
        }
    }
    
    public boolean isCellEditable(int row, int column) {
        return false;
    }    

    public void setPreferredWidth(int idx, int preferredWidth) {
        if (idx < 0){
            return;
        }
        if (getColumnCount()-1 < idx) {
            return;
        }
        getColumnModel().getColumn(idx).setPreferredWidth(preferredWidth);
    }
    
    public void autoResizeColumnWidth() {
        Font headerFont = getTableHeader().getFont();
        FontMetrics fontMetrics = getFontMetrics(headerFont);

        for (int i=0; i<getColumnCount(); i++) {
            if (i==0 && showRowNumber) {
                getColumnModel().getColumn(0).setPreferredWidth(30);
            }

            int width = fontMetrics.stringWidth(getColumnName(i))+20;
            TableColumn column = getColumnModel().getColumn(i);
            if (width > column.getWidth()) {
                column.setPreferredWidth(width);
            }            
        }
    }

    public void addRow(ArrayList rowList) {
        DefaultTableModel defaultTableModel = (DefaultTableModel)getModel();
        synchronized (defaultTableModel) {
            Vector rowVector = new Vector();
            if (showRowNumber) {
                rowVector.add(new Integer(this.getRowCount()+1));
            }
            rowVector.addAll(rowList);
            defaultTableModel.addRow(rowVector);
        }
    }
    
    public void addRow(Vector rowVector) {
        DefaultTableModel defaultTableModel = (DefaultTableModel)getModel();
        synchronized (defaultTableModel) {
            if (showRowNumber) {
                rowVector.add(0, new Integer(this.getRowCount()+1));
            }
            defaultTableModel.addRow(rowVector);
        }
    }    
    
    public void removeAllRows() {
        int rowCount = getRowCount();
        DefaultTableModel defaultTableModel = (DefaultTableModel)getModel();
        synchronized (defaultTableModel) {
            for (int i=0; i<rowCount; i++) {
                defaultTableModel.removeRow(0);
            }
        }
    }
    
    public Object getValueAt(int row, String columnName) {
        for(int i=0; i<getColumnCount(); i++) {
            String currentColumnName = getColumnModel().getColumn(i).getHeaderValue().toString();
            if (currentColumnName.equals(columnName)) {
                return this.getValueAt(row, i);
            }
        }
        return null;
    }
    
}
