/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;

import java.awt.Adjustable;
import java.awt.BorderLayout;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;

import net.kldp.whitebear.handler.MainHandler;

public class SqlResultPanel extends JPanel implements AdjustmentListener {
    private static final long serialVersionUID = 1769023909176518582L;
    private JScrollPane jScrollPane = null;
    private ReadOnlyTable readOnlyTable = null;
    private JTextField jtMsg = null;
    private MainHandler mainHandler = null;
    
    public SqlResultPanel() {
        super();
        initialize();
    }

    public SqlResultPanel(MainHandler mainHandler) {
        super();
        this.mainHandler = mainHandler;
        initialize();
    }
    
    private void initialize() {
        this.setLayout(new BorderLayout());
        this.setSize(new java.awt.Dimension(300,200));
        this.add(getJScrollPane(), java.awt.BorderLayout.CENTER);
        this.getJScrollPane().getVerticalScrollBar().addAdjustmentListener(this);
        this.add(getJtMsg(), java.awt.BorderLayout.SOUTH);
    }
    
    public void adjustmentValueChanged(AdjustmentEvent e) {
        Adjustable adjustable = (Adjustable)e.getAdjustable();
        
        int tableHeight = getReadOnlyTable().getHeight();
        int currentHeight = adjustable.getValue()+adjustable.getVisibleAmount();

        if ( tableHeight==0 || currentHeight==0 ) {
            return;
        }
        
        boolean valueIsAdjusting = this.getJScrollPane().getVerticalScrollBar().getValueIsAdjusting();
        if ( currentHeight >= tableHeight && valueIsAdjusting == false ) {
            mainHandler.getMainFrame().executeNext();
        }
    }
    
    private JScrollPane getJScrollPane() {
        if (jScrollPane == null) {
            jScrollPane = new JScrollPane();
            jScrollPane.setViewportView(getReadOnlyTable());
        }
        return jScrollPane;
    }

    public ReadOnlyTable getReadOnlyTable() {
        if (readOnlyTable == null) {
            readOnlyTable = new ReadOnlyTable(true);
        }
        return readOnlyTable;
    }
    
    public void setReadOnlyTable(ReadOnlyTable readOnlyTable) {
        this.readOnlyTable = null;
        this.readOnlyTable = readOnlyTable;
        getJScrollPane().setViewportView(readOnlyTable);
    }

    public JTextField getJtMsg() {
        if (jtMsg == null) {
            jtMsg = new JTextField();
            jtMsg.setEditable(false);
        }
        return jtMsg;
    }
    
}
