/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;

import java.awt.BorderLayout;
import java.sql.DatabaseMetaData;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreeSelectionModel;

import net.kldp.whitebear.common.entity.ColumnRef;
import net.kldp.whitebear.common.entity.DatabaseInfo;
import net.kldp.whitebear.common.entity.TableRef;
import net.kldp.whitebear.common.entity.TableTreeNodeInfo;
import net.kldp.whitebear.handler.MainHandler;

public class TableTreePanel extends JPanel implements TreeSelectionListener {
    private static final long serialVersionUID = -6571846798403168690L;
    private JScrollPane jScrollPane = null;
    private JTree jTree = null;
    private MainHandler mainHandler;
    
    public TableTreePanel() {
        super();
        initialize();
    }
    
    public void setMainHandler(MainHandler mainHandler) {
        this.mainHandler = mainHandler;
    }    
    
    public void valueChanged(TreeSelectionEvent e) {
    	DefaultMutableTreeNode node = (DefaultMutableTreeNode)this.getJTree().getLastSelectedPathComponent();        
        if (node == null) return;

        TableTreeNodeInfo tableTreeNodeInfo = (TableTreeNodeInfo)node.getUserObject();
        int type = tableTreeNodeInfo.getType();
        if (type == TableTreeNodeInfo.NODE_TYPE_TABLE) {
            showTableInfo(tableTreeNodeInfo);
        } else if (type == TableTreeNodeInfo.NODE_TYPE_TOP) {
            showDatabaseInfo();
        }
    }
    
    private void showTableInfo(TableTreeNodeInfo tableTreeNodeInfo) {
        DatabaseMetaData dbMeta = mainHandler.getJdbcHandler().getDatabaseMetaData();
        TableRef tableRef = (TableRef)tableTreeNodeInfo.getInfo();
        ArrayList columns = mainHandler.getJdbcHandler().getColumns(dbMeta, tableRef.getCategory(), tableRef.getTABLE_NAME());
        TableInfoPanel tableInfoPanel = mainHandler.getMainFrame().getCenterPanel().getWorkSpacePanel().getInfoPanel().getTableInfoPanel();
        mainHandler.getMainFrame().getCenterPanel().getWorkSpacePanel().getInfoPanel().setShowPanel(InfoPanel.TABLE_INFO_PANEL);
        ReadOnlyTable readOnlyTable = tableInfoPanel.getReadOnlyTable();
        readOnlyTable.removeAllRows();
        for (int i=0; i<columns.size(); i++) {
            ColumnRef columnRef = (ColumnRef)columns.get(i);
            Vector rowVector = new Vector();
            rowVector.add(columnRef.getCOLUMN_NAME      ());
            rowVector.add(columnRef.getTYPE_NAME        ());
            rowVector.add(new Integer(columnRef.getCOLUMN_SIZE()));
            rowVector.add(new Integer(columnRef.getDECIMAL_DIGITS()));
            rowVector.add(columnRef.getIS_NULLABLE      ());
            rowVector.add(columnRef.getCOLUMN_DEF       ());
            rowVector.add(columnRef.getREMARKS          ());
            rowVector.add(columnRef.getTABLE_CAT        ());
            rowVector.add(columnRef.getTABLE_SCHEM      ());
            rowVector.add(columnRef.getTABLE_NAME       ());
            rowVector.add(new Integer(columnRef.getDATA_TYPE        ()));
            rowVector.add(new Integer(columnRef.getNUM_PREC_RADIX   ()));
            rowVector.add(new Integer(columnRef.getNULLABLE         ()));
            rowVector.add(new Integer(columnRef.getCHAR_OCTET_LENGTH()));
            rowVector.add(new Integer(columnRef.getORDINAL_POSITION ()));
            rowVector.add(columnRef.getSCOPE_CATLOG     ());
            rowVector.add(columnRef.getSCOPE_SCHEMA     ());
            rowVector.add(columnRef.getSCOPE_TABLE      ());
            rowVector.add(new Integer(columnRef.getSOURCE_DATA_TYPE ()));
            readOnlyTable.addRow(rowVector);
        }
    }

    private void showDatabaseInfo() {
        DatabaseMetaData dbMeta = mainHandler.getJdbcHandler().getDatabaseMetaData();
        DatabaseInfoPanel databaseInfoPanel = mainHandler.getMainFrame().getCenterPanel().getWorkSpacePanel().getInfoPanel().getDatabaseInfoPanel();
        mainHandler.getMainFrame().getCenterPanel().getWorkSpacePanel().getInfoPanel().setShowPanel(InfoPanel.DATABASE_INFO_PANEL);
        ReadOnlyTable readOnlyTable = databaseInfoPanel.getReadOnlyTable();
        DatabaseInfo databaseInfo = mainHandler.getJdbcHandler().getDatabaseInfo(dbMeta);
        readOnlyTable.removeAllRows();
        addDatabaseInfoToTable(readOnlyTable,"All Procedures Are Callable"               ,databaseInfo.isAllProceduresAreCallable());
        addDatabaseInfoToTable(readOnlyTable,"All Tables Are Selectable"                 ,databaseInfo.isAllTablesAreSelectable());
        addDatabaseInfoToTable(readOnlyTable,"Data Definition Causes Transaction Commit" ,databaseInfo.isDataDefinitionCausesTransactionCommit());
        addDatabaseInfoToTable(readOnlyTable,"Data Definition Ignored In Transactions"   ,databaseInfo.isDataDefinitionIgnoredInTransactions());
        addDatabaseInfoToTable(readOnlyTable,"Max Row Size Include Blobs"                ,databaseInfo.isMaxRowSizeIncludeBlobs());
        addDatabaseInfoToTable(readOnlyTable,"Catalog Separator"                         ,databaseInfo.getCatalogSeparator());
        addDatabaseInfoToTable(readOnlyTable,"Catalog Term"                              ,databaseInfo.getCatalogTerm());
        addDatabaseInfoToTable(readOnlyTable,"Database Major Version"                    ,databaseInfo.getDatabaseMajorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Database Minor Version"                    ,databaseInfo.getDatabaseMinorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Database Product Name"                     ,databaseInfo.getDatabaseProductName());
        addDatabaseInfoToTable(readOnlyTable,"Database Product Version"                  ,databaseInfo.getDatabaseProductVersion());
        addDatabaseInfoToTable(readOnlyTable,"Default Transaction Isolation"             ,databaseInfo.getDefaultTransactionIsolation());
        addDatabaseInfoToTable(readOnlyTable,"Driver Major Version"                      ,databaseInfo.getDriverMajorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Driver Minor Version"                      ,databaseInfo.getDatabaseMinorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Driver Name"                               ,databaseInfo.getDriverName());
        addDatabaseInfoToTable(readOnlyTable,"Driver Version"                            ,databaseInfo.getDriverVersion());
        addDatabaseInfoToTable(readOnlyTable,"Extra Name Characters"                     ,databaseInfo.getExtraNameCharacters());
        addDatabaseInfoToTable(readOnlyTable,"Identifier QuoteString"                    ,databaseInfo.getIdentifierQuoteString());
        addDatabaseInfoToTable(readOnlyTable,"Jdbc Major Version"                        ,databaseInfo.getJdbcMajorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Jdbc Minor Version"                        ,databaseInfo.getJdbcMinorVersion());
        addDatabaseInfoToTable(readOnlyTable,"Max Binary Literal Length"                 ,databaseInfo.getMaxBinaryLiteralLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Catalog Name Length"                   ,databaseInfo.getMaxCatalogNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Char Literal Length"                   ,databaseInfo.getMaxColumnNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Column Name Length"                    ,databaseInfo.getMaxColumnNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Columns In Group By"                   ,databaseInfo.getMaxColumnsInGroupBy());
        addDatabaseInfoToTable(readOnlyTable,"Max Columns In Index"                      ,databaseInfo.getMaxColumnsInIndex());
        addDatabaseInfoToTable(readOnlyTable,"Max Columns In Order By"                   ,databaseInfo.getMaxColumnsInOrderBy());
        addDatabaseInfoToTable(readOnlyTable,"Max Columns In Select"                     ,databaseInfo.getMaxColumnsInSelect());
        addDatabaseInfoToTable(readOnlyTable,"Max Columns In Table"                      ,databaseInfo.getMaxColumnsInTable());
        addDatabaseInfoToTable(readOnlyTable,"Max Connections"                           ,databaseInfo.getMaxConnections());
        addDatabaseInfoToTable(readOnlyTable,"Max Cursor Name Length"                    ,databaseInfo.getMaxCursorNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Index Length"                          ,databaseInfo.getMaxIndexLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Procedure Name Length"                 ,databaseInfo.getMaxProcedureNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Row Size"                              ,databaseInfo.getMaxRowSize());
        addDatabaseInfoToTable(readOnlyTable,"Max Schema Name Length"                    ,databaseInfo.getMaxSchemaNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Statement Length"                      ,databaseInfo.getMaxStatementLength());
        addDatabaseInfoToTable(readOnlyTable,"Max Statements"                            ,databaseInfo.getMaxStatements());
        addDatabaseInfoToTable(readOnlyTable,"Max Table Name Length"                     ,databaseInfo.getMaxTableNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Max User Name Length"                      ,databaseInfo.getMaxUserNameLength());
        addDatabaseInfoToTable(readOnlyTable,"Numeric Functions"                         ,databaseInfo.getNumericFunctions());
        addDatabaseInfoToTable(readOnlyTable,"Procedure Term"                            ,databaseInfo.getProcedureTerm());
        addDatabaseInfoToTable(readOnlyTable,"ResultSet Holdability"                     ,databaseInfo.getResultSetHoldability());
        addDatabaseInfoToTable(readOnlyTable,"Schema Term"                               ,databaseInfo.getSchemaTerm());
        addDatabaseInfoToTable(readOnlyTable,"Search String Escape"                      ,databaseInfo.getSearchStringEscape());
        addDatabaseInfoToTable(readOnlyTable,"SQL Keywords"                              ,databaseInfo.getSQLKeywords());
        addDatabaseInfoToTable(readOnlyTable,"SQL State Type"                            ,databaseInfo.getSQLStateType());
        addDatabaseInfoToTable(readOnlyTable,"String Functions"                          ,databaseInfo.getStringFunctions());
        addDatabaseInfoToTable(readOnlyTable,"System Functions"                          ,databaseInfo.getSystemFunctions());
        addDatabaseInfoToTable(readOnlyTable,"Time Date Functions"                       ,databaseInfo.getTimeDateFunctions());
        addDatabaseInfoToTable(readOnlyTable,"Url"                                       ,databaseInfo.getUrl());
        addDatabaseInfoToTable(readOnlyTable,"User Name"                                 ,databaseInfo.getUserName());
        addDatabaseInfoToTable(readOnlyTable,"Catalog At Start"                          ,databaseInfo.isCatalogAtStart());
        addDatabaseInfoToTable(readOnlyTable,"Is Read Only"                              ,databaseInfo.isReadOnly());
        addDatabaseInfoToTable(readOnlyTable,"Locators Update Copy"                      ,databaseInfo.isLocatorsUpdateCopy());
        addDatabaseInfoToTable(readOnlyTable,"Null Plus Non Null Is Null"                ,databaseInfo.isNullPlusNonNullIsNull());
        addDatabaseInfoToTable(readOnlyTable,"Nulls Are Sorted At End"                   ,databaseInfo.isNullsAreSortedAtEnd());
    }
    
    private void addDatabaseInfoToTable(ReadOnlyTable readOnlyTable, Object name, boolean value) {
        Vector rowVector = new Vector();
        rowVector.add(name);
        rowVector.add(new Boolean(value));
        readOnlyTable.addRow(rowVector);
    }

    private void addDatabaseInfoToTable(ReadOnlyTable readOnlyTable, Object name, Object value) {
        Vector rowVector = new Vector();
        rowVector.add(name);
        rowVector.add(value);
        readOnlyTable.addRow(rowVector);
    }

    private void addDatabaseInfoToTable(ReadOnlyTable readOnlyTable, Object name, int value) {
        Vector rowVector = new Vector();
        rowVector.add(name);
        rowVector.add(new Integer(value));
        readOnlyTable.addRow(rowVector);
    }
    
    private void initialize() {
        this.setLayout(new BorderLayout());
        this.setSize(new java.awt.Dimension(300,200));
        this.add(getJScrollPane(), java.awt.BorderLayout.CENTER);
        this.getJTree().addTreeSelectionListener(this);
        this.getJTree().getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);            
    }
    
    public void setRoot(TreeNode root) {
        DefaultTreeModel dtm = (DefaultTreeModel)getJTree().getModel();
        dtm.setRoot(root);
    }

    private JScrollPane getJScrollPane() {
        if (jScrollPane == null) {
            jScrollPane = new JScrollPane();
            jScrollPane.setViewportView(getJTree());
        }
        return jScrollPane;
    }

    public JTree getJTree() {
        if (jTree == null) {
            jTree = new JTree();
        }
        return jTree;
    }

}
