/*
 *  Copyright 2005 Youjin Lee
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

package net.kldp.whitebear.handler.ui.swing;


import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JPopupMenu;
import javax.swing.JTabbedPane;

import net.kldp.whitebear.common.entity.QueryResult;
import net.kldp.whitebear.handler.MainHandler;

public class WorkSpacePanel extends JPanel implements MouseListener, ActionListener {
    private static final long serialVersionUID = 4631500360430463346L;

    public static final String SQL_PANEL = "SQL";
    public static final String INFO_PANEL = "INFO";
    
    private JTabbedPane jTabbedPane = null;
    private InfoPanel infoPanel = null;
    private MainHandler mainHandler = null;

    private JPopupMenu jPopupMenu;
    private JMenuItem jmiClose;
    
    public MainHandler getMainHandler() {
        return mainHandler;
    }

    public void setMainHandler(MainHandler mainHandler) {
        this.mainHandler = mainHandler;
    }    
    
    public WorkSpacePanel() {
        super();
        initialize();
    }

    private void initialize() {
        this.setLayout(new BorderLayout());
        this.setSize(300, 200);
        createPopupMenu();
        this.add(getJTabbedPane(), java.awt.BorderLayout.CENTER);
        getJTabbedPane().addMouseListener(this);
        getJmiClose().addActionListener(this);
    }

    public JTabbedPane getJTabbedPane() {
        if (jTabbedPane == null) {
            jTabbedPane = new JTabbedPane();
            jTabbedPane.addTab(INFO_PANEL, getInfoPanel());
        }
        return jTabbedPane;
    }    

    public InfoPanel getInfoPanel() {
        if (infoPanel == null) {
            infoPanel = new InfoPanel();
        }
        return infoPanel;        
    }

    private void createPopupMenu() {
        getJPopupMenu();
    }    

    public JPopupMenu getJPopupMenu() {
        if (jPopupMenu == null) {
            jPopupMenu = new JPopupMenu();
            jPopupMenu.add(getJmiClose());
        }
        return jPopupMenu;
    }

    public JMenuItem getJmiClose() {
        if (jmiClose == null) {
            jmiClose = new JMenuItem();
            jmiClose.setText("Close");
        }
        return jmiClose;
    }   
    
    public void mouseClicked(MouseEvent e) {
        
    }

    public void mouseEntered(MouseEvent e) {
        
    }

    public void mouseExited(MouseEvent e) {
        
    }

    public void mousePressed(MouseEvent e) {
        if (e.getButton()==MouseEvent.BUTTON3) {
            int idx = this.getJTabbedPane().indexAtLocation(e.getX(), e.getY()); 
            if (idx == -1) {
                return;
            }
            Component component = getJTabbedPane().getComponentAt(idx);
            if (component instanceof SqlPanel) {
                getJPopupMenu().show(e.getComponent(), e.getX(), e.getY());
            }
        }
    }

    public void mouseReleased(MouseEvent e) {

    }

    public void actionPerformed(ActionEvent e) {
        if (e.getSource().equals(getJmiClose())) {
            int idx = this.getJTabbedPane().getSelectedIndex();
            SqlPanel sqlPanel = (SqlPanel)this.getJTabbedPane().getSelectedComponent();
            QueryResult queryResult = sqlPanel.getQueryResult();
            if (queryResult!=null) {
                queryResult.close();
            }
            this.getJTabbedPane().removeTabAt(idx);
        }
    }
    
}
