package net.kldp.whitebear.test;

import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.util.ArrayList;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreeSelectionModel;

import net.kldp.whitebear.common.entity.DbConnectInfo;
import net.kldp.whitebear.common.entity.TableRef;
import net.kldp.whitebear.common.variable.DBTypes;
import net.kldp.whitebear.handler.JdbcHandler;

public class TableViewTest extends JFrame implements WindowListener, TreeSelectionListener {
    private static final long serialVersionUID = 1L;

    private DefaultMutableTreeNode topTableNode;
    private DbConnectInfo dbConnectInfo;
    private JdbcHandler jdbcHandler;
    private JTree jtree; 
    
    protected TableViewTest() {
        try {
            dbConnectInfo = new DbConnectInfo();
            dbConnectInfo.setDbtype(DBTypes.DB_TYPE_MYSQL);
            dbConnectInfo.setDbName("mysql");
            dbConnectInfo.setHost("localhost");
            dbConnectInfo.setPort("3306");
            dbConnectInfo.setUserName("root");
            dbConnectInfo.setPassword("");
            topTableNode = new DefaultMutableTreeNode("mysql");
            
            jdbcHandler = new JdbcHandler(dbConnectInfo);
            
            makeTableTree();
            addWindowListener(this);
            jtree = new JTree(topTableNode);
            jtree.addTreeSelectionListener(this);
            jtree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);            
            
            JScrollPane js = new JScrollPane(jtree);
            getContentPane().add(js);
            setSize(300,300);
            setVisible(true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public static void main(String[] args) {
        new TableViewTest();
    }
    
    private void makeTableTree() {
        ArrayList categories = jdbcHandler.getCategories(jdbcHandler.getDatabaseMetaData());
        if (categories!=null) {
            for (int i=0; i<categories.size(); i++) {
                String category = (String)categories.get(i); 
                DefaultMutableTreeNode categoryNode = new DefaultMutableTreeNode(category);
                
                ArrayList tables = jdbcHandler.getTables(jdbcHandler.getDatabaseMetaData(), category);
                if (tables!=null) {
                    for (int j=0; j<tables.size(); j++) {
                        TableRef t = (TableRef)tables.get(j);
                        DefaultMutableTreeNode tableNode = new DefaultMutableTreeNode(t.getTABLE_NAME()+" ["+t.getTABLE_TYPE()+"]");
                        categoryNode.add(tableNode);
                    }
                }
                topTableNode.add(categoryNode);
            }            
        }
    }

    public void windowActivated(WindowEvent e) {
        
    }

    public void windowClosed(WindowEvent e) {
        
    }

    public void windowClosing(WindowEvent e) {
        System.exit(1);
    }

    public void windowDeactivated(WindowEvent e) {
        
    }

    public void windowDeiconified(WindowEvent e) {
        
    }

    public void windowIconified(WindowEvent e) {
        
    }

    public void windowOpened(WindowEvent e) {
        
    }

    public void valueChanged(TreeSelectionEvent e) {
        DefaultMutableTreeNode node = (DefaultMutableTreeNode)jtree.getLastSelectedPathComponent();        
        if (node == null) return;

        Object o = node.getUserObject();
        System.out.println(o.getClass().getName());
    }
    
}
